@@ -28,7 +28,11 @@
 
 QLabelW::QLabelW(const QString &text, bool isLabel, QWidget *parent, Qt::WindowFlags f) : QLabel (text, parent, f) {
 	this->isLabel = isLabel;
-	setContextMenuPolicy(Qt::CustomContextMenu);
+
+	if (!isLabel) {
+		setContextMenuPolicy(Qt::CustomContextMenu);
+		QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(labelMenu(const QPoint&)));
+	}
 }
 
 QLabelW::QLabelW(QWidget *parent, Qt::WindowFlags f): QLabel (parent, f) {
@@ -37,6 +41,36 @@ QLabelW::QLabelW(QWidget *parent, Qt::WindowFlags f): QLabel (parent, f) {
 QLabelW::~QLabelW() {
 }
 
+void QLabelW::labelMenu(const QPoint & _p) {
+   	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
+
+	if (f->value != NULL && f->value.length() > 0) {
+		QMenu menu(this);
+		if (f->type == TYPE_URL) {
+			menu.addAction(tr("Go to"), this, SLOT(m_goto()));
+			menu.addAction(tr("Copy"), this, SLOT(m_copy()));
+			//QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
+		}
+		else {
+			if (f->type == TYPE_PHONE_NUMBER) {
+				QString telf = f->value;
+				telf = telf.simplified();
+				telf = telf.replace(" ", "");
+
+				if (telf.length() > 0) {
+					menu.addAction(tr("Call to").arg(telf), this, SLOT(m_call()));
+				}
+				//menu.addAction(tr("SMS to"), tmp, SLOT(m_sms()));
+				menu.addAction(tr("Copy"), this, SLOT(m_copy()));
+			}
+			else {
+				menu.addAction(tr("Copy"), this, SLOT(m_copy()));
+			}
+		}
+		menu.exec(_p);
+	}
+}
+
 void QLabelW::m_copy () {
    	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
 
@@ -65,6 +99,10 @@ void QLabelW::m_call () {
 		if (f->type == TYPE_PHONE_NUMBER) {
 //    				QSettings settings;
 
+
+//			XQTelephony *telephony = new XQTelephony(this);
+//			telephony->call("+919464763259");//caller number
+
 			QString telf = f->value;
 			telf = telf.simplified();
 			telf = telf.replace(" ", "");
@@ -223,10 +261,10 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		if (!isNew)
 			menuBar()->addAction(tr("Delete"), this, SLOT(_deleteTarget()));
 		menuBar()->addAction(tr("Change Face Pict."), this, SLOT(cardFace()));
-		menuBar()->addAction(tr("Mirror Face Pict."), this, SLOT(mirrorFace()));
+		//menuBar()->addAction(tr("Mirror Face Pict."), this, SLOT(mirrorFace()));
 		menuBar()->addAction(tr("Rotate Face Pict."), this, SLOT(rotateFace()));
 		menuBar()->addAction(tr("Change Back Pict."), this, SLOT(cardBack()));
-		menuBar()->addAction(tr("Mirror Back Pict."), this, SLOT(mirrorBack()));
+		//menuBar()->addAction(tr("Mirror Back Pict."), this, SLOT(mirrorBack()));
 		menuBar()->addAction(tr("Rotate Back Pict."), this, SLOT(rotateBack()));
 		menuBar()->addAction(tr("Delete Face Pict."), this, SLOT(deleteCardFace()));
 		menuBar()->addAction(tr("Delete Back Pict."), this, SLOT(deleteCardBack()));
@@ -238,12 +276,12 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 			m->addAction(tr("Delete"), this, SLOT(_deleteTarget()));
 		m = menuBar()->addMenu(tr("Pictures"));
 		m->addAction(tr("Change Face Pict."), this, SLOT(cardFace()));
-		m->addAction(tr("Mirror Face Pict."), this, SLOT(mirrorFace()));
+		//m->addAction(tr("Mirror Face Pict."), this, SLOT(mirrorFace()));
 		m->addAction(tr("Rotate Face Pict."), this, SLOT(rotateFace()));
 		m->addAction(tr("Delete Face Pict."), this, SLOT(deleteCardFace()));
 		m->addSeparator ();
 		m->addAction(tr("Change Back Pict."), this, SLOT(cardBack()));
-		m->addAction(tr("Mirror Back Pict."), this, SLOT(mirrorBack()));
+		//m->addAction(tr("Mirror Back Pict."), this, SLOT(mirrorBack()));
 		m->addAction(tr("Rotate Back Pict."), this, SLOT(rotateBack()));
 		m->addAction(tr("Delete Back Pict."), this, SLOT(deleteCardBack()));
 		m = menuBar()->addMenu(tr("Others"));
@@ -403,7 +441,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 	componentLayout = new QGridLayout ();
 
-	QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardMenu(const QPoint&)));
+	//QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardMenu(const QPoint&)));
 
 	if (edit || this->target->getPicture() != NULL) {
 		imageLabel = new QLabel(this);
@@ -428,8 +466,8 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 			imageLabel->setPixmap(QPixmap::fromImage (*currentImage));
 		}
 		
-		//imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
-		//QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardFaceMenu(const QPoint&)));
+		imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
+		QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardFaceMenu(const QPoint&)));
 #ifdef Q_WS_MAEMO_5
 		if (edit) {
 			componentLayout->addWidget(imageLabel, 3, 0, 2, 3);
@@ -469,8 +507,8 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 			imageBackLabel->setPixmap(QPixmap::fromImage (*currentImageBack));
 		}
 
-		//imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
-		//QObject::connect(imageBackLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardBackMenu(const QPoint&)));
+		imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
+		QObject::connect(imageBackLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardBackMenu(const QPoint&)));
 
 #ifdef Q_WS_MAEMO_5
 		if (edit) {
@@ -1010,86 +1048,87 @@ void DetailWindow::loadImage (QString q, QImage& res) {
 	////qDebug () << "read " << q << " as (" << imageSize << ") with result " << reader.errorString ();
 }
 
-void DetailWindow::labelMenu(const QPoint & _p) {
-	QMenu menu(this);
-	menu.addAction(tr("View"), this, SLOT(cardFace()));
-	menu.exec(_p);
-}
+//void DetailWindow::labelMenu(const QPoint & _p) {
+//	QMenu menu(this);
+//	menu.addAction(tr("View"), this, SLOT(cardFace()));
+//	menu.exec(_p);
+//}
 
-void DetailWindow::cardMenu(const QPoint & _p) {
-	QPoint p = _p;//this->mapFromGlobal(_p);
+//void DetailWindow::cardMenu(const QPoint & _p) {
+//	QPoint p = _p;//this->mapFromGlobal(_p);
+//
+//	QScrollBar* bar = entryScrollArea->verticalScrollBar();
+//
+//	if (bar)
+//		p.setY(p.y() + bar->value());
+//
+//	QWidget * tmp = centralWidget->childAt(p);
+//	qDebug () << tmp;
+//
+//	entryScrollArea->ensureVisible(p.x(), p.y());
+//
+//	if (this->imageLabel != NULL && this->imageLabel->geometry().contains(p)) {
+//		QMenu menu(this);
+//		if (edit) {
+//			menu.addAction(tr("Edit"), this, SLOT(cardFace()));
+//			//menu.addAction(tr("Mirror"), this, SLOT(mirrorFace()));
+//			menu.addAction(tr("Rotate"), this, SLOT(rotateFace()));
+//			menu.addAction(tr("Delete"), this, SLOT(deleteCardFace()));
+//		}
+//		else {
+//			menu.addAction(tr("Export Face"), this, SLOT(exportCardFace()));
+//		}
+//		menu.exec(_p);
+//	}
+//	else
+//	if (this->imageBackLabel != NULL && this->imageBackLabel->geometry().contains(p)) {
+//		QMenu menu(this);
+//		if (edit) {
+//			menu.addAction(tr("Edit"), this, SLOT(cardBack()));
+//			//menu.addAction(tr("Mirror"), this, SLOT(mirrorBack()));
+//			menu.addAction(tr("Rotate"), this, SLOT(rotateBack()));
+//			menu.addAction(tr("Delete"), this, SLOT(deleteCardBack()));
+//		}
+//		else {
+//			menu.addAction(tr("Export Back"), this, SLOT(exportCardBack()));
+//		}
+//		menu.exec(_p);
+//	}
+//	else {
+//		if (tmp != NULL) {
+//			if (tmp->userData(0) != NULL) {
+//				TargetField * f = ((ButtonInfo *)tmp->userData(0))->field;
+//
+//				if (f->value != NULL && f->value.length() > 0) {
+//					QMenu menu(this);
+//					if (f->type == TYPE_URL) {
+//						menu.addAction(tr("Go to"), tmp, SLOT(m_goto()));
+//						menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
+//						//QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
+//					}
+//					else {
+//						if (f->type == TYPE_PHONE_NUMBER) {
+//							QString telf = f->value;
+//							telf = telf.simplified();
+//							telf = telf.replace(" ", "");
+//
+//							if (telf.length() > 0) {
+//								menu.addAction(tr("Call to").arg(telf), tmp, SLOT(m_call()));
+//							}
+//							//menu.addAction(tr("SMS to"), tmp, SLOT(m_sms()));
+//							menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
+//						}
+//						else {
+//							menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
+//						}
+//					}
+//					menu.exec(_p);
+//				}
+//			}
+//		}
+//	}
+//}
 
-	QScrollBar* bar = entryScrollArea->verticalScrollBar();
-
-	if (bar)
-		p.setY(p.y() + bar->value());
-
-	QWidget * tmp = centralWidget->childAt(p);
-	//qDebug () << tmp;
-
-	entryScrollArea->ensureVisible(p.x(), p.y());
-
-	if (this->imageLabel != NULL && this->imageLabel->geometry().contains(p)) {
-		QMenu menu(this);
-		if (edit) {
-			menu.addAction(tr("Edit"), this, SLOT(cardFace()));
-			menu.addAction(tr("Mirror"), this, SLOT(mirrorFace()));
-			menu.addAction(tr("Rotate"), this, SLOT(rotateFace()));
-			menu.addAction(tr("Delete"), this, SLOT(deleteCardFace()));
-		}
-		else {
-			menu.addAction(tr("Export Face"), this, SLOT(exportCardFace()));
-		}
-		menu.exec(_p);
-	}
-	else
-	if (this->imageBackLabel != NULL && this->imageBackLabel->geometry().contains(p)) {
-		QMenu menu(this);
-		if (edit) {
-			menu.addAction(tr("Edit"), this, SLOT(cardBack()));
-			menu.addAction(tr("Mirror"), this, SLOT(mirrorBack()));
-			menu.addAction(tr("Rotate"), this, SLOT(rotateBack()));
-			menu.addAction(tr("Delete"), this, SLOT(deleteCardBack()));
-		}
-		else {
-			menu.addAction(tr("Export Back"), this, SLOT(exportCardBack()));
-		}
-		menu.exec(_p);
-	}
-	else {
-		if (tmp != NULL) {
-			if (tmp->userData(0) != NULL) {
-				TargetField * f = ((ButtonInfo *)tmp->userData(0))->field;
-
-				if (f->value != NULL && f->value.length() > 0) {
-					QMenu menu(this);
-					if (f->type == TYPE_URL) {
-						menu.addAction(tr("Go to"), tmp, SLOT(m_goto()));
-						menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
-						//QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
-					}
-					else {
-						if (f->type == TYPE_PHONE_NUMBER) {
-							QString telf = f->value;
-							telf = telf.simplified();
-							telf = telf.replace(" ", "");
-
-							if (telf.length() > 0) {
-								menu.addAction(tr("Call to").arg(telf), tmp, SLOT(m_call()));
-							}
-							//menu.addAction(tr("SMS to"), tmp, SLOT(m_sms()));
-							menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
-						}
-						else {
-							menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
-						}
-					}
-					menu.exec(_p);
-				}
-			}
-		}
-	}
-}
 void DetailWindow::deleteCardFace()
 {
 	QPixmap available(":/resources/empty_card.png");
@@ -1225,36 +1264,32 @@ void DetailWindow::rotateBack () {
 //void DetailWindow::contextMenuEvent (QContextMenuEvent * event) {
 //	//qDebug () << "NOW";
 //}
-//void DetailWindow::cardBackMenu(const QPoint & pos) {
-//
-//	////qDebug () << "MENU";
-//
-//	QMenu menu(this);
-//	if (edit) {
-//		menu.addAction("Edit", this, SLOT(cardBack()));
-//		menu.addAction("Mirror", this, SLOT(mirrorBack()));
-//		menu.addAction("Delete", this, SLOT(deleteCardBack()));
-//	}
-//	else {
-//		menu.addAction("Export", this, SLOT(exportCardBack()));
-//	}
-//	menu.exec(pos);
-//}
-//void DetailWindow::cardFaceMenu(const QPoint & pos) {
-//
-//	////qDebug () << "MENU";
-//
-//	QMenu menu(this);
-//	if (edit) {
-//		menu.addAction("Edit", this, SLOT(cardFace()));
-//		menu.addAction("Mirror", this, SLOT(mirrorFace()));
-//		menu.addAction("Delete", this, SLOT(deleteCardFace()));
-//	}
-//	else {
-//		menu.addAction("Export", this, SLOT(exportCardFace()));
-//	}
-//	menu.exec(pos);
-//}
+void DetailWindow::cardFaceMenu(const QPoint & pos) {
+	QMenu menu(this);
+	if (edit) {
+		menu.addAction(tr("Edit"), this, SLOT(cardFace()));
+		//menu.addAction(tr("Mirror"), this, SLOT(mirrorFace()));
+		menu.addAction(tr("Rotate"), this, SLOT(rotateFace()));
+		menu.addAction(tr("Delete"), this, SLOT(deleteCardFace()));
+	}
+	else {
+		menu.addAction(tr("Export Face"), this, SLOT(exportCardFace()));
+	}
+	menu.exec(pos);
+}
+void DetailWindow::cardBackMenu(const QPoint & pos) {
+	QMenu menu(this);
+	if (edit) {
+		menu.addAction(tr("Edit"), this, SLOT(cardBack()));
+		//menu.addAction(tr("Mirror"), this, SLOT(mirrorBack()));
+		menu.addAction(tr("Rotate"), this, SLOT(rotateBack()));
+		menu.addAction(tr("Delete"), this, SLOT(deleteCardBack()));
+	}
+	else {
+		menu.addAction(tr("Export Back"), this, SLOT(exportCardBack()));
+	}
+	menu.exec(pos);
+}
 
 
 void DetailWindow::orientationChanged(int o) {
