@@ -126,10 +126,10 @@ public slots:
 	void deleteCardBack();
 	void exportCardBack();
 
-	void cardMenu(const QPoint & pos);
-	void labelMenu(const QPoint & pos);
-//	void cardFaceMenu(const QPoint & pos);
-//	void cardBackMenu(const QPoint & pos);
+//	void cardMenu(const QPoint & pos);
+//	void labelMenu(const QPoint & pos);
+	void cardFaceMenu(const QPoint & pos);
+	void cardBackMenu(const QPoint & pos);
 //	void contextMenuEvent (QContextMenuEvent * event);
 
 	void emitCommitData (int);
@@ -165,6 +165,7 @@ public:
 	QLabelW(QWidget *parent=0, Qt::WindowFlags f=0);
 	~QLabelW();
 public slots:
+	void labelMenu(const QPoint & _p);
 	void m_copy ();
 	void m_goto ();
 	void m_sms ();
