@@ -154,6 +154,7 @@ eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 	isShowGroups = 0;
 
 #ifdef Q_WS_MAEMO_5
+
 	this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 	connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
@@ -886,7 +887,7 @@ void eWallet::showGroups(bool reset)
 //	fnListWidget->setIconSize (QSize (SMALL_WIDTH, SMALL_HEIGH));
 //	fnListWidget->setContentsMargins(10, 1, 0, 1);
 
-	QListWidgetItem* listitem = new QListWidgetItem(tr("<All>"), fnListWidget);
+	QListWidgetItem* listitem = new QListWidgetItem(tr("<All>"));
 
 	//listitem->set(target->getSummary());
 	fnListWidget->addItem(listitem);
@@ -896,10 +897,10 @@ void eWallet::showGroups(bool reset)
 
 		QListWidgetItem * listitem;
 		if (target.length() == 0) {
-			listitem = new QListWidgetItem(tr("<No Group>"), fnListWidget);
+			listitem = new QListWidgetItem(tr("<No Group>"));
 		}
 		else {
-			listitem = new QListWidgetItem(target, fnListWidget);
+			listitem = new QListWidgetItem(target);
 		}
 		//listitem->set(target->getSummary());
 		fnListWidget->addItem(listitem);
@@ -967,7 +968,7 @@ void eWallet::showTargets(bool reset, const QString * filter)
 	for (int i = 0; i < list.size (); i++) {
 		Target * target = list.at(i);
 
-		QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->getName (), fnListWidget);
+		QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->getName ());
 		//listitem->set(target->getSummary());
 		fnListWidget->addItem(listitem);
 		
@@ -1001,8 +1002,9 @@ void eWallet::createMenu()
 	}
 	else {
 		menuBar()->addAction(tr("New"), this, SLOT(newTarget()));
-		if (isShowGroups == 2)
+		if (isShowGroups == 2) {
 			menuBar()->addAction(tr("Edit"), this, SLOT(_editcTarget()));
+		}
 		menuBar()->addAction(tr("Invert Sort"), this, SLOT(sort()));
 		menuBar()->addAction(tr("Import"), this, SLOT(import()));
 		menuBar()->addAction(tr("Export"), this, SLOT(exportData()));
@@ -1069,22 +1071,22 @@ bool eWallet::_insertTarget(Target* target)
 		if (isShowGroups == 2) {
 			list.append(target);
 
-	//		if (ascSort)
-	//			qSort (list.begin(),list.end(),sortTargetsASC);
-	//		else
-	//			qSort (list.begin(),list.end(),sortTargetsDES);
+			if (ascSort)
+				qSort (list.begin(),list.end(),sortTargetsASC);
+			else
+				qSort (list.begin(),list.end(),sortTargetsDES);
 
-			QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name, fnListWidget);
+			QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name);
 
 			int pos = list.indexOf(target);
-			//qDebug () << "position of new " << pos << " OF " << list.size ();
+			qDebug () << "position of new " << pos << " OF " << list.size ();
 
 			if (pos < list.size()) {
-				////qDebug () << "insert position of new " << pos << " OF " << list.size ();
+				qDebug () << "insert position of new " << pos << " OF " << list.size ();
 				fnListWidget->insertItem(pos, listitem);
 			}
 			else {
-				////qDebug () << "append position of new " << pos << " OF " << list.size ();
+				qDebug () << "append position of new " << pos << " OF " << list.size ();
 				fnListWidget->addItem(listitem);
 			}
 			fnListWidget->setCurrentItem(listitem);
@@ -1142,7 +1144,57 @@ bool eWallet::_updateTarget(Target* target)
 		if (isShowGroups == 2) {
 			int i = list.indexOf(target);
 			QListWidgetItem* listitem = fnListWidget->item (i);
+
+			// check if the group has been changed
+			bool changedGroup = false;
+			if (list.length() > 1) {
+				if (i > 1)
+					changedGroup = target->groupName != list.at(i - 1)->groupName;
+				else
+					changedGroup = target->groupName != list.at(i + 1)->groupName;
+			}
+			else {
+				// TODO detect that group has been changed and reload all group!!!!
+
+			}
+
+			qDebug () << "group has been changed !!!!" << changedGroup;
+
 			listitem->setText(target->name);
+
+			if (changedGroup) {
+				delete list.takeAt(i);
+				delete fnListWidget->takeItem(i);
+			}
+			else {
+				if (list.length() > 1) {
+					if (ascSort)
+						qSort (list.begin(),list.end(),sortTargetsASC);
+					else
+						qSort (list.begin(),list.end(),sortTargetsDES);
+
+					int pos = list.indexOf(target);
+					qDebug () << "position of new " << pos << " OF " << list.size ();
+
+					if (i != pos) {
+						fnListWidget->takeItem(i);
+						if (pos < i) {
+							fnListWidget->insertItem(pos, listitem);
+						}
+						else {
+							if (pos < list.size()) {
+								qDebug () << "insert position of new " << pos << " OF " << list.size ();
+								fnListWidget->insertItem(pos, listitem);
+							}
+							else {
+								qDebug () << "append position of new " << pos << " OF " << list.size ();
+								fnListWidget->addItem(listitem);
+							}
+						}
+					}
+				}
+				fnListWidget->setCurrentItem(listitem);
+			}
 		}
 		else {
 			showGroups(true);
